==> estateplat-common-1.2.4-20210521.012200-772-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdcbnydsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 土地承包经营权、农用地使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_tdcbnydsyq")
public class BdcTdcbnydsyq extends QllxParent {
    /* @Id
  private String qlid;//权利Id
  private String bdcdyid;//不动产单元Id*/
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private String syttlx;//水域滩涂类型
    private String yzyfs;//养殖业方式
    private String cyzl;//草原质量
    private Integer syzcl;//适宜载畜量
    private Double syqmj;//承包（使用权）面积（亩）
    private String tdsyqxz;//土地所有权性质
    private String ywh;//业务号
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private String fbfmc;//发包方名称
    private String qdcbfs;//取得承包方式
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private Double ccgd;//草层高度
    private String cdysz;//草地优势种
    private String cdjq;//草地建群
    private String cdfgd;//草地覆盖度
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_tdcbnydsyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getQdcbfs() {
        return qdcbfs;
    }

    public void setQdcbfs(String qdcbfs) {
        this.qdcbfs = qdcbfs;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public Double getCcgd() {
        return ccgd;
    }

    public void setCcgd(Double ccgd) {
        this.ccgd = ccgd;
    }

    public String getCdysz() {
        return cdysz;
    }

    public void setCdysz(String cdysz) {
        this.cdysz = cdysz;
    }

    public String getCdjq() {
        return cdjq;
    }

    public void setCdjq(String cdjq) {
        this.cdjq = cdjq;
    }

    public String getCdfgd() {
        return cdfgd;
    }

    public void setCdfgd(String cdfgd) {
        this.cdfgd = cdfgd;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }
}

==> estateplat-common-1.2.4-20230427.031625-1165-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdcbnydsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 土地承包经营权、农用地使用权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_tdcbnydsyq")
public class BdcTdcbnydsyq extends QllxParent {
    /* @Id
  private String qlid;//权利Id
  private String bdcdyid;//不动产单元Id*/
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private String syttlx;//水域滩涂类型
    private String yzyfs;//养殖业方式
    private String cyzl;//草原质量
    private Integer syzcl;//适宜载畜量
    private Double syqmj;//承包（使用权）面积（亩）
    private String tdsyqxz;//土地所有权性质
    private String ywh;//业务号
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记

    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private String fbfmc;//发包方名称
    private String qdcbfs;//取得承包方式
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private Double ccgd;//草层高度
    private String cdysz;//草地优势种
    private String cdjq;//草地建群
    private String cdfgd;//草地覆盖度
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_tdcbnydsyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况
    private String fbfdm ;//发包方代码
    private String cbhtbm ;//承包合同代码
    private String ydyhfl ;//用地用海分类
    private String tdcbht ;//土地承包合同

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getQdcbfs() {
        return qdcbfs;
    }

    public void setQdcbfs(String qdcbfs) {
        this.qdcbfs = qdcbfs;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public Double getCcgd() {
        return ccgd;
    }

    public void setCcgd(Double ccgd) {
        this.ccgd = ccgd;
    }

    public String getCdysz() {
        return cdysz;
    }

    public void setCdysz(String cdysz) {
        this.cdysz = cdysz;
    }

    public String getCdjq() {
        return cdjq;
    }

    public void setCdjq(String cdjq) {
        this.cdjq = cdjq;
    }

    public String getCdfgd() {
        return cdfgd;
    }

    public void setCdfgd(String cdfgd) {
        this.cdfgd = cdfgd;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    @Override
    public Integer getCxzt() {
        return cxzt;
    }

    @Override
    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getCbhtbm() {
        return cbhtbm;
    }

    public void setCbhtbm(String cbhtbm) {
        this.cbhtbm = cbhtbm;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdcbht() {
        return tdcbht;
    }

    public void setTdcbht(String tdcbht) {
        this.tdcbht = tdcbht;
    }
}
